Learn R Programming

pnn (version 0.9.0)

category.probs: Calculate the probabilities of each category given X

Description

Calculate the probabilities of each category given X

Usage

category.probs(nn, X)

Arguments

X
Pattern from which we have to decide a category. It is a set of measurements represented by a p-dimensional vector
nn
An already trained probabilistic neural network