Learn R Programming

pnn (version 0.9.0)

fA: Sum the results of applying the kernel over all patterns

Description

Sum the results of applying the kernel over all patterns

Usage

fA(Xa, X, sigma)

Arguments

X
Pattern from which we have to decide a category. It is a set of measurements represented by a p-dimensional vector
Xa
One of the training patterns from category A
sigma
Smoothing parameter