Learn R Programming

pnn (version 0.9.0)

learn: Training the PNN

Description

Training the PNN

Usage

learn(set, category.column = 1, nn)

Arguments

set
Data frame with the training set of all categories: one column should have the category and others the associated measurements
category.column
The field number of the factor
nn
An empty probabilistic neural network